@@ -6,3 +6,5 @@ from .lib.evaluator import DetectionEvaluator
 from .lib.utils import *
 from .lib.labelme import *
 from .lib.labelme_utils import *
+from .lib.anno import *
+from .lib.dm import DMDet, DMMC, DMML
