@@ -45,9 +45,6 @@ class DataManager(object):
         self.record_list = record_list
         self.class_dict = class_dict
 
-        # Incorporate the Annotation Manager
-        self.am = AnnotationManager(class_dict)
-
     def filter(self, condition_callback, verbose=False):
         """
         Filter data by the given condition
