@@ -48,10 +48,10 @@ class ClassifierEvalBinary(ClassifierEval):
             y_true: 1维nparray, 所有样本的真值列表[nSamples], e.g., [0, 1, 1, 0], 1为ng, 0为ok
             y_score: 1维nparray, 所有样本在目标类别上的分数, 注意该分数是最后一层(softmax层)的输出结果。e.g., [0.2, 0.9, 0.4, 0.5]
         Return:
-            一个数字：AP值。
+            一个数字:AP值。
         """
         if np.sum(y_true) <= 0:
-            ap = np.nan
+            ap = 0
         else:
             ap = metrics.average_precision_score(y_true=y_true, y_score=y_score)
         return round(ap, 6)
@@ -142,11 +142,11 @@ class ClassifierEvalBinary(ClassifierEval):
         yes_counter = 0
 
         def distance_square_cal(recall, precision):
-            return recall**2 + precision**2
+            return recall * precision
 
-        inflection_recall = np.nan
-        inflection_precision = np.nan
-        inflection_score = np.nan
+        inflection_recall = 0
+        inflection_precision = 0
+        inflection_score = 1
         max_distance_square = 0
         if total_yes > 0:
             for ix, (score, lb) in enumerate(bundle):
@@ -303,7 +303,7 @@ class ClassifierEvalBinary(ClassifierEval):
         recall_threshold = 0.05
         sample_num_thre = 6
 
-        threshold = sys.maxsize
+        threshold = 1
         total_num = 0
         correct_num = 0
         for score, label in bundle:
@@ -345,7 +345,7 @@ class ClassifierEvalMulticlass(ClassifierEval):
             y_true: 1维nparray, 所有样本的真值列表[nSamples], e.g., [2, 0, 3]
             y_score: 1维nparray, 所有样本在各个类上的分数, e.g., [[0.2, 0.7, 0.1, 0], [0.1, 0.3, 0.5, 0.1], [0.4, 0.2, 0.1, 0.3]]
         Return:
-            每个类别的Precision@(Recall>=recall_thresh)组成的dict, 如{0: 0.2345, 1： 0.2344, 2： 0.7623, 3： 0.3334}
+            每个类别的Precision@(Recall>=recall_thresh)组成的dict, 如{0: 0.2345, 1: 0.2344, 2: 0.7623, 3: 0.3334}
         """
         label_list = sorted(list(set(y_true)))  # label从小到大排序
         prec_dict = dict()
@@ -504,10 +504,10 @@ class ClassifierEvalMultilabel(ClassifierEval):
                 key = class_name_list[i]
             else:
                 key = i
-            ap_dict[key] = ap
             if np.isnan(ap):
-                # warnings.warn(RuntimeWarning("ap of class {} is nan, you'd better check the data you are testing".format(key)))
-                pass
+                ap = 0
+            ap_dict[key] = ap
+
         return ap_dict
 
     @classmethod
@@ -517,7 +517,7 @@ class ClassifierEvalMultilabel(ClassifierEval):
             y_true: 2维nparray, 所有样本的真值列表[nSamples, nClasses], e.g., [[0, 0, 1, 0], [1, 0, 0, 0], [0, 0, 0, 1]]
             y_score: 1维nparray, 所有样本在各个类上的分数, e.g., [[0.2, 0.7, 0.1, 0], [0.1, 0.3, 0.5, 0.1], [0.4, 0.2, 0.1, 0.3]]
         Return:
-            每个类别的Precision@(Recall>=recall_thresh)组成的dict, 如{0: 0.2345, 1： 0.2344, 2： 0.7623, 3： 0.3334}
+            每个类别的Precision@(Recall>=recall_thresh)组成的dict, 如{0: 0.2345, 1: 0.2344, 2: 0.7623, 3: 0.3334}
         """
         prec_dict = dict()
         for i, (true_per_cls, score_per_cls) in enumerate(zip(y_true.T, y_score.T)):
@@ -695,7 +695,7 @@ class ClassifierEvalMultilabel(ClassifierEval):
     def get_threshold_at_p(cls, y_true, y_score, precision_thresh=0.9, class_name_list=None):
         """
         计算各个类别在precision处于precision_thresh水平下最小阈值, 不存在则返回最大int值
-        args：
+        args:
             y_true: 2维nparray, 所有样本的真值列表[nSamples, nClasses], e.g., [[0, 0, 1, 0], [0, 0, 0, 1], [0, 1, 0, 0], [1, 0, 0, 0]]
             y_score: 2维nparray, 所有样本在各个类上的分数, e.g., [[0.2, 0.7, 0.1, 0], [0.1, 0.3, 0.5, 0.1], [0.4, 0.2, 0.1, 0.3], [0.3, 0.3, 0.4, 0]]
             precision_thresh: precision 阈值 [0, 1]
