@@ -2,6 +2,7 @@
 # Adapted from mmdetection/mmdet/core/evaluation/mean_ap.py
 #
 import numpy as np
+from ....utils_vvd import ListOrderedDict
 from multiprocessing import Pool
 
 def bbox_overlaps(bboxes1, bboxes2, mode='iou', eps=1e-6):
@@ -313,6 +314,7 @@ def get_cls_results(det_results, annotations, class_id):
 
 def eval_map(det_results,
              annotations,
+             classnames=None,
              scale_ranges=None,
              iou_thr=0.5,
              dataset=None,
@@ -360,7 +362,12 @@ def eval_map(det_results,
                    if scale_ranges is not None else None)
 
     pool = Pool(nproc)
-    eval_results = []
+    if classnames is not None:
+        assert len(classnames) == num_classes, f" len(classnames) is not eaqul to num_classes."
+        assert num_classes == len(set(classnames)), f"same key in classnames {classnames}"
+        eval_results = ListOrderedDict()
+    else:
+        eval_results = list()
     for i in range(num_classes):
         # get gt and det bboxes of this class
         cls_dets, cls_gts, cls_gts_ignore = get_cls_results(
@@ -398,11 +405,14 @@ def eval_map(det_results,
         cls_dets = np.vstack(cls_dets)
         num_dets = cls_dets.shape[0]
         sort_inds = np.argsort(-cls_dets[:, -1])
+
         tp = np.hstack(tp)[:, sort_inds]
         fp = np.hstack(fp)[:, sort_inds]
+        
+        scores = np.sort(cls_dets[:, -1])[::-1]
         # calculate recall and precision with tp and fp
         tp = np.cumsum(tp, axis=1)
-        fp = np.cumsum(fp, axis=1)
+        fp = np.cumsum(fp, axis=1) 
         eps = np.finfo(np.float32).eps
         recalls = tp / np.maximum(num_gts[:, np.newaxis], eps)
         precisions = tp / np.maximum((tp + fp), eps)
@@ -413,13 +423,18 @@ def eval_map(det_results,
             num_gts = num_gts.item()
         mode = 'area' if dataset != 'voc07' else '11points'
         ap = average_precision(recalls, precisions, mode)
-        eval_results.append({
-            'num_gts': num_gts,
-            'num_dets': num_dets,
-            'recall': recalls,
-            'precision': precisions,
-            'ap': ap
-        })
+        res_dict = {
+                'num_gts': num_gts,
+                'num_dets': num_dets,
+                'recall': recalls,
+                'precision': precisions,
+                'score': scores,
+                'ap': ap
+            }
+        if classnames is not None:
+            eval_results[classnames[i]] = res_dict
+        else:
+            eval_results.append(res_dict)
     pool.close()
     if scale_ranges is not None:
         # shape (num_classes, num_scales)
