@@ -19,6 +19,7 @@ from .utils import OS_exists
 from .utils import time_reduce
 from .utils import glob_recursively
 from .utils import has_chinese_char
+from .utils import vvd_floor
 
 from tqdm import tqdm
 from pathlib import Path
@@ -1013,4 +1014,79 @@ def close_op(image, kernal_size, kermal_type=None):
     ksize = [W, H]
     kermal_type in ['rec', 'circle', 'cross']
     """
-    return morphology_op(image, 'close', kernal_size, kermal_type)
\ No newline at end of file
+    return morphology_op(image, 'close', kernal_size, kermal_type)
+
+
+def image_center_paste(image, canvas):
+    assert image.ndim == canvas.ndim
+    I_H, I_W = image.shape[:2]
+    C_H, C_W = canvas.shape[:2]
+    
+    assert C_H >= I_H and C_W >= I_W, f"image shape {image.shape} is larger than canvas' {canvas.shape}"
+    
+    H_gap = C_H - I_H
+    W_gap = C_W - I_W
+    
+    top = vvd_floor(H_gap / 2)
+    down = top + I_H
+    left = vvd_floor(W_gap / 2)
+    right = left + I_W
+    
+    canvas[top:down, left:right, ...] = image
+    return canvas
+
+def puzzle(image_list):
+    image_num = len(image_list)
+    col_num = int(np.ceil(image_num**0.5))
+    row_num = int(np.ceil(image_num/col_num))
+
+    margin = 20 
+
+    col_size = [ -1 for _ in range(col_num)]
+    row_size = [ -1 for _ in range(row_num)]
+
+    ndim = -1
+
+    for row_index in range(row_num):
+        base = row_index * col_num
+        for col_index in range(col_num):
+            image_index = col_index + base
+            if image_index >= image_num:
+                break
+            H, W = image_list[image_index].shape[:2]
+            row_size[row_index] = H if H > row_size[row_index] else row_size[row_index]
+            col_size[col_index] = W if W > col_size[col_index] else col_size[col_index]
+            ndim = image_list[image_index].ndim if image_list[image_index].ndim > ndim else ndim
+
+    assert ndim in [2, 3]
+    assert np.min(col_size) > 0 and np.min(row_size) > 0
+
+    Image_H = np.sum(row_size) + (row_num - 1) * margin
+    Image_W = np.sum(col_size) + (col_num - 1) * margin
+
+    if ndim == 2:
+        image = np.zeros([Image_H, Image_W], dtype='uint8')
+    elif ndim == 3:
+        image = np.zeros([Image_H, Image_W, 3], dtype='uint8')
+    else:
+        raise ValueError(f"bad ndim value {ndim}")
+
+    for row_index in range(row_num):
+        base = row_index * col_num
+        for col_index in range(col_num):
+            image_index = col_index + base
+            if image_index >= image_num:
+                break
+
+            top = np.sum(row_size[:row_index]).astype('int') + row_index * margin
+            down = top + row_size[row_index]
+            left = np.sum(col_size[:col_index]).astype('int') + col_index * margin
+            right = left + col_size[col_index]
+            
+            crop = image[top:down, left:right, ...]
+            cur_image = image_list[image_index]
+            if ndim == 3:
+                cur_image = to_colorful_image(cur_image)
+            image_center_paste(cur_image, crop)
+
+    return image
