@@ -12,6 +12,7 @@ import os.path as osp
 from os.path import basename as OS_basename
 from os.path import join as OS_join
 from os.path import exists as OS_exists
+from os.path import isfile as OS_isfile
 from os.path import isdir as OS_isdir
 from os.path import dirname as OS_dirname
 import string
@@ -364,6 +365,11 @@ def create_uuid():
     md5_hash = hashlib.md5(uuid.uuid1().bytes)
     return md5_hash.hexdigest()
 
+def xor(A, B):
+    if (A and not B) or (B and not A):
+        return True
+    else:
+        return False
 
 def get_file_hash_code(file):
     """
@@ -631,7 +637,7 @@ def time_stamp():
     return time.strftime("%Y-%m-%d_%H-%M-%S", time.localtime())
 
 
-def smart_copy(source_file_path, target_path, verbose=False, remove_source_file=False):
+def smart_copy(source_file_path, target_path, verbose=False, remove_source_file=False, overwrite=False):
     """[复制文件从源到目标，如果目标已经存在则跳过]]
 
     Args:
@@ -644,12 +650,15 @@ def smart_copy(source_file_path, target_path, verbose=False, remove_source_file=
     assert OS_exists(source_file_path)
     if OS_isdir(target_path):
         target_path = OS_join(target_path, OS_basename(source_file_path))
-    if OS_exists(target_path):
+    exists = OS_exists(target_path)
+    if exists and not overwrite:
         if verbose:
-            print("{} already exists!".format(target_path))
+            print("{} already exists! skip copying.".format(target_path))
     else:
         dir_check(Path(target_path).parent)
-
+        if exists and overwrite:
+            if verbose:
+                print("{} already exists! start overwriting.".format(target_path))
         if remove_source_file:
             shutil.move(source_file_path, target_path)
         else:
@@ -1343,6 +1352,13 @@ def random_string(length, digits=True, letters=True, punctuation=True):
     return ''.join(random.choice(str_temp) for _ in range(length))
 
 
+def remove_file(path):
+    path = str(path)
+    if OS_exists(path):
+        if OS_isfile(path):
+            os.remove(path)
+
+
 if __name__ == '__main__':
     LOD = ListOrderedDict()
     LOD['a'] = 'a content'
